@@ -21,9 +21,9 @@ class addone(object):
     def addtest(self):
         print(self.number + 1)
         print('Random numpy integer: ' + str(np.random.randint(4)))
-        sample_df = pd.DataFrame(pd.read_csv('data/sample_data.csv'))
+        #sample_df = pd.DataFrame(pd.read_csv('data/sample_data.csv'))
         print(list_files(''))
-        print(sample_df.to_markdown())
+        #print(sample_df.to_markdown())
 
 def main():
     parser = argparse.ArgumentParser(formatter_class=argparse.ArgumentDefaultsHelpFormatter)
